@@ -113,7 +113,7 @@ Tags other users have given to this Photo.
 	    photo => $self->id, 
 	    person=> { '!=', $user},
 	    },{
-	select     => [ 'me.tag', 'count(me.tag)' ],
+	select     => [ 'me.tag', 'count(me.tag) AS refcount' ],
 	as         => [ 'tag','refcount' ],
 	'group_by' => ['me.tag'],
     'order_by' => 'refcount',
@@ -190,4 +190,4 @@ sub make_thumb {
     $result->write(file=>$att->filename.'.thumb',type=>'jpeg') or die $img->errstr;
 }
 
-1;
\ No newline at end of file
+1;
